'use client'
import * as React from "react"
import {
    Card,
    CardDescription,
    CardFooter,
    CardHeader,
    CardTitle,
} from "@/components/ui/card"

import {
  Tooltip,
  TooltipContent,
  TooltipProvider,
  TooltipTrigger,
} from "@/components/ui/tooltip"

import { Avatar, AvatarImage } from "../ui/avatar";
import Link from "next/link";
import { Label } from "../ui/label";


export const MoreAvatarTooltip = ({lista}) => {
    let grid;

    switch (lista.length) {
        case 1:
            grid = 'grid-cols-1';
            break;
        case 2:
            grid = 'grid-cols-2';
            break;
        default:
            grid = 'grid-cols-3';
    }

    return(
        <TooltipProvider>
            <Tooltip>
                <TooltipTrigger asChild>
                    <div className="bg-tertiary border-[1px] border-backgroundDark w-[38px] h-[38px] rounded-full">
                        <div className="py-[6px] text-center">
                            +{lista.length}
                        </div>
                    </div>
                </TooltipTrigger>
                <TooltipContent className={`w-fit relative top-24 left-2 grid ${grid} gap-2`}>
                    {lista.map((element, index) => {
                        return(
                            <Avatar key={index}>
                                <AvatarImage src="https://github.com/shadcn.png" alt="@shadcn" />
                            </Avatar>
                        )
                    })}
                </TooltipContent>
            </Tooltip>
        </TooltipProvider>
    );
}

export const SetAvatar = ({participants}) => { 
    let lista = [];
    return(
        <div className="flex space-x-1.5">  
            {participants.map((element, index) => {          
                if (index < 5 ) {
                    return ( 
                        <Avatar key={index}>
                            <AvatarImage src="https://github.com/shadcn.png" alt="@shadcn" />
                        </Avatar>
                    )
                }else{
                    lista.push(element);
                    return null;
                }
            })}
            {lista.length > 0 &&
                <MoreAvatarTooltip lista={lista}/>
            }
        </div>
        
    )
} 

export default function RoomCard({name, description, participants}) {

    return (
        <Link href={`/chats/${name}`}>
            <Card className="w-full h-full bg-background border-none m-1 inline-table pb-2">
                <CardHeader className="h-[75%]">
                    <CardTitle className="text-secondary">{name}</CardTitle>
                    <CardDescription className="text-tertiary pt-2">      
                        {description.length > 200 ? 
                            <TooltipProvider>
                                <Tooltip>
                                    <TooltipTrigger asChild>
                                        <Label>{`${description.substring(0,200)}`} <br/> {"(...)"}</Label>
                                    </TooltipTrigger>
                                    <TooltipContent className="w-[400px] relative top-24 ">
                                        {description}
                                    </TooltipContent>
                                </Tooltip>
                            </TooltipProvider>
                        : description}
                    </CardDescription>
                </CardHeader>
                <CardFooter className="justify-end lg:grid xl:flex">
                    <SetAvatar participants={participants}/>
                </CardFooter>
            </Card>
        </Link>
    );
}